Class: GriffNode::TransactionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/griffnode/api/transactions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TransactionsApi

Returns a new instance of TransactionsApi.



19
20
21
# File 'lib/griffnode/api/transactions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/griffnode/api/transactions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_detailed_transaction(create_detailed_transaction_request, opts = {}) ⇒ TransactionEnvelope

Create an itemized transaction (Professional/Enterprise plans)

Parameters:

Options Hash (opts):

  • :x_idempotency_key (String)

    Optional unique key for a create request (e.g. a UUID). A retried create with the same key returns the original transaction instead of creating a duplicate — send it on every create so a network retry can't double-charge the customer.

Returns:



27
28
29
30
# File 'lib/griffnode/api/transactions_api.rb', line 27

def create_detailed_transaction(create_detailed_transaction_request, opts = {})
  data, _status_code, _headers = create_detailed_transaction_with_http_info(create_detailed_transaction_request, opts)
  data
end

#create_detailed_transaction_with_http_info(create_detailed_transaction_request, opts = {}) ⇒ Array<(TransactionEnvelope, Integer, Hash)>

Create an itemized transaction (Professional/Enterprise plans)

Parameters:

Options Hash (opts):

  • :x_idempotency_key (String)

    Optional unique key for a create request (e.g. a UUID). A retried create with the same key returns the original transaction instead of creating a duplicate — send it on every create so a network retry can't double-charge the customer.

Returns:

  • (Array<(TransactionEnvelope, Integer, Hash)>)

    TransactionEnvelope data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/griffnode/api/transactions_api.rb', line 37

def create_detailed_transaction_with_http_info(create_detailed_transaction_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransactionsApi.create_detailed_transaction ...'
  end
  # verify the required parameter 'create_detailed_transaction_request' is set
  if @api_client.config.client_side_validation && create_detailed_transaction_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_detailed_transaction_request' when calling TransactionsApi.create_detailed_transaction"
  end
  # resource path
  local_var_path = '/transactions/create-detailed'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Idempotency-Key'] = opts[:'x_idempotency_key'] if !opts[:'x_idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_detailed_transaction_request)

  # return_type
  return_type = opts[:debug_return_type] || 'TransactionEnvelope'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['SecretKey']

  new_options = opts.merge(
    :operation => :"TransactionsApi.create_detailed_transaction",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionsApi#create_detailed_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_transaction(create_transaction_request, opts = {}) ⇒ TransactionEnvelope

Create a payment transaction

Parameters:

Options Hash (opts):

  • :x_idempotency_key (String)

    Optional unique key for a create request (e.g. a UUID). A retried create with the same key returns the original transaction instead of creating a duplicate — send it on every create so a network retry can't double-charge the customer.

Returns:



96
97
98
99
# File 'lib/griffnode/api/transactions_api.rb', line 96

def create_transaction(create_transaction_request, opts = {})
  data, _status_code, _headers = create_transaction_with_http_info(create_transaction_request, opts)
  data
end

#create_transaction_with_http_info(create_transaction_request, opts = {}) ⇒ Array<(TransactionEnvelope, Integer, Hash)>

Create a payment transaction

Parameters:

Options Hash (opts):

  • :x_idempotency_key (String)

    Optional unique key for a create request (e.g. a UUID). A retried create with the same key returns the original transaction instead of creating a duplicate — send it on every create so a network retry can't double-charge the customer.

Returns:

  • (Array<(TransactionEnvelope, Integer, Hash)>)

    TransactionEnvelope data, response status code and response headers



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/griffnode/api/transactions_api.rb', line 106

def create_transaction_with_http_info(create_transaction_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransactionsApi.create_transaction ...'
  end
  # verify the required parameter 'create_transaction_request' is set
  if @api_client.config.client_side_validation && create_transaction_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_transaction_request' when calling TransactionsApi.create_transaction"
  end
  # resource path
  local_var_path = '/transactions/create'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Idempotency-Key'] = opts[:'x_idempotency_key'] if !opts[:'x_idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_transaction_request)

  # return_type
  return_type = opts[:debug_return_type] || 'TransactionEnvelope'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['SecretKey']

  new_options = opts.merge(
    :operation => :"TransactionsApi.create_transaction",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionsApi#create_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_transaction(transaction_id, opts = {}) ⇒ TransactionEnvelope

Retrieve a single transaction

Parameters:

  • transaction_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



164
165
166
167
# File 'lib/griffnode/api/transactions_api.rb', line 164

def get_transaction(transaction_id, opts = {})
  data, _status_code, _headers = get_transaction_with_http_info(transaction_id, opts)
  data
end

#get_transaction_with_http_info(transaction_id, opts = {}) ⇒ Array<(TransactionEnvelope, Integer, Hash)>

Retrieve a single transaction

Parameters:

  • transaction_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TransactionEnvelope, Integer, Hash)>)

    TransactionEnvelope data, response status code and response headers



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/griffnode/api/transactions_api.rb', line 173

def get_transaction_with_http_info(transaction_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransactionsApi.get_transaction ...'
  end
  # verify the required parameter 'transaction_id' is set
  if @api_client.config.client_side_validation && transaction_id.nil?
    fail ArgumentError, "Missing the required parameter 'transaction_id' when calling TransactionsApi.get_transaction"
  end
  # resource path
  local_var_path = '/transactions/{transaction_id}'.sub('{' + 'transaction_id' + '}', CGI.escape(transaction_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'TransactionEnvelope'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['SecretKey']

  new_options = opts.merge(
    :operation => :"TransactionsApi.get_transaction",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionsApi#get_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_transactions(opts = {}) ⇒ ListTransactions200Response

List the merchant's transactions (newest first)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



228
229
230
231
# File 'lib/griffnode/api/transactions_api.rb', line 228

def list_transactions(opts = {})
  data, _status_code, _headers = list_transactions_with_http_info(opts)
  data
end

#list_transactions_with_http_info(opts = {}) ⇒ Array<(ListTransactions200Response, Integer, Hash)>

List the merchant's transactions (newest first)

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(ListTransactions200Response, Integer, Hash)>)

    ListTransactions200Response data, response status code and response headers



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/griffnode/api/transactions_api.rb', line 240

def list_transactions_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TransactionsApi.list_transactions ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TransactionsApi.list_transactions, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling TransactionsApi.list_transactions, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0
    fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling TransactionsApi.list_transactions, must be greater than or equal to 0.'
  end

  # resource path
  local_var_path = '/transactions/list'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'crypto'] = opts[:'crypto'] if !opts[:'crypto'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListTransactions200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['SecretKey']

  new_options = opts.merge(
    :operation => :"TransactionsApi.list_transactions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TransactionsApi#list_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end