Class: GriffNode::WebhookPayload

Inherits:
Object
  • Object
show all
Defined in:
lib/griffnode/models/webhook_payload.rb

Overview

Payment-event payload. AMOUNTS ARE STRINGS (e.g. "100.00", "0.00109462") to preserve decimal precision — parse before arithmetic.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/griffnode/models/webhook_payload.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `GriffNode::WebhookPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `GriffNode::WebhookPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end

  if attributes.key?(:'transaction_id')
    self.transaction_id = attributes[:'transaction_id']
  else
    self.transaction_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'currency_crypto')
    self.currency_crypto = attributes[:'currency_crypto']
  end

  if attributes.key?(:'currency_fiat')
    self.currency_fiat = attributes[:'currency_fiat']
  else
    self.currency_fiat = 'USD'
  end

  if attributes.key?(:'amount_fiat')
    self.amount_fiat = attributes[:'amount_fiat']
  end

  if attributes.key?(:'amount_usd')
    self.amount_usd = attributes[:'amount_usd']
  end

  if attributes.key?(:'amount_crypto')
    self.amount_crypto = attributes[:'amount_crypto']
  end

  if attributes.key?(:'order_id')
    self.order_id = attributes[:'order_id']
  end

  if attributes.key?(:'receipt_url')
    self.receipt_url = attributes[:'receipt_url']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#amount_cryptoObject

Decimal string.



38
39
40
# File 'lib/griffnode/models/webhook_payload.rb', line 38

def amount_crypto
  @amount_crypto
end

#amount_fiatObject

Decimal string.



32
33
34
# File 'lib/griffnode/models/webhook_payload.rb', line 32

def amount_fiat
  @amount_fiat
end

#amount_usdObject

Decimal string.



35
36
37
# File 'lib/griffnode/models/webhook_payload.rb', line 35

def amount_usd
  @amount_usd
end

#currency_cryptoObject

Returns the value of attribute currency_crypto.



27
28
29
# File 'lib/griffnode/models/webhook_payload.rb', line 27

def currency_crypto
  @currency_crypto
end

#currency_fiatObject

Returns the value of attribute currency_fiat.



29
30
31
# File 'lib/griffnode/models/webhook_payload.rb', line 29

def currency_fiat
  @currency_fiat
end

#eventObject

Returns the value of attribute event.



19
20
21
# File 'lib/griffnode/models/webhook_payload.rb', line 19

def event
  @event
end

#metadataObject

Free-form key/value (≤20 keys, string values ≤500 chars, ≤4 KB total).



46
47
48
# File 'lib/griffnode/models/webhook_payload.rb', line 46

def 
  @metadata
end

#order_idObject

Returns the value of attribute order_id.



40
41
42
# File 'lib/griffnode/models/webhook_payload.rb', line 40

def order_id
  @order_id
end

#receipt_urlObject

Present on completed/overpaid.



43
44
45
# File 'lib/griffnode/models/webhook_payload.rb', line 43

def receipt_url
  @receipt_url
end

#statusObject

Returns the value of attribute status.



25
26
27
# File 'lib/griffnode/models/webhook_payload.rb', line 25

def status
  @status
end

#timestampObject

Returns the value of attribute timestamp.



21
22
23
# File 'lib/griffnode/models/webhook_payload.rb', line 21

def timestamp
  @timestamp
end

#transaction_idObject

Returns the value of attribute transaction_id.



23
24
25
# File 'lib/griffnode/models/webhook_payload.rb', line 23

def transaction_id
  @transaction_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/griffnode/models/webhook_payload.rb', line 300

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = GriffNode.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/griffnode/models/webhook_payload.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/griffnode/models/webhook_payload.rb', line 71

def self.attribute_map
  {
    :'event' => :'event',
    :'timestamp' => :'timestamp',
    :'transaction_id' => :'transaction_id',
    :'status' => :'status',
    :'currency_crypto' => :'currency_crypto',
    :'currency_fiat' => :'currency_fiat',
    :'amount_fiat' => :'amount_fiat',
    :'amount_usd' => :'amount_usd',
    :'amount_crypto' => :'amount_crypto',
    :'order_id' => :'order_id',
    :'receipt_url' => :'receipt_url',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/griffnode/models/webhook_payload.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
117
# File 'lib/griffnode/models/webhook_payload.rb', line 112

def self.openapi_nullable
  Set.new([
    :'order_id',
    :'receipt_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/griffnode/models/webhook_payload.rb', line 94

def self.openapi_types
  {
    :'event' => :'String',
    :'timestamp' => :'Time',
    :'transaction_id' => :'String',
    :'status' => :'TransactionStatus',
    :'currency_crypto' => :'CryptoSymbol',
    :'currency_fiat' => :'FiatCurrency',
    :'amount_fiat' => :'String',
    :'amount_usd' => :'String',
    :'amount_crypto' => :'String',
    :'order_id' => :'String',
    :'receipt_url' => :'String',
    :'metadata' => :'Hash<String, String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/griffnode/models/webhook_payload.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event == o.event &&
      timestamp == o.timestamp &&
      transaction_id == o.transaction_id &&
      status == o.status &&
      currency_crypto == o.currency_crypto &&
      currency_fiat == o.currency_fiat &&
      amount_fiat == o.amount_fiat &&
      amount_usd == o.amount_usd &&
      amount_crypto == o.amount_crypto &&
      order_id == o.order_id &&
      receipt_url == o.receipt_url &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/griffnode/models/webhook_payload.rb', line 371

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/griffnode/models/webhook_payload.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/griffnode/models/webhook_payload.rb', line 269

def hash
  [event, timestamp, transaction_id, status, currency_crypto, currency_fiat, amount_fiat, amount_usd, amount_crypto, order_id, receipt_url, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/griffnode/models/webhook_payload.rb', line 197

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  if @transaction_id.nil?
    invalid_properties.push('invalid value for "transaction_id", transaction_id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
# File 'lib/griffnode/models/webhook_payload.rb', line 347

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/griffnode/models/webhook_payload.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



341
342
343
# File 'lib/griffnode/models/webhook_payload.rb', line 341

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



221
222
223
224
225
226
227
228
229
230
# File 'lib/griffnode/models/webhook_payload.rb', line 221

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["payment.created", "payment.pending", "payment.completed", "payment.overpaid", "payment.partial", "payment.expired", "payment.failed"])
  return false unless event_validator.valid?(@event)
  return false if @timestamp.nil?
  return false if @transaction_id.nil?
  return false if @status.nil?
  true
end