Class: GriffNode::AccountApi
- Inherits:
-
Object
- Object
- GriffNode::AccountApi
- Defined in:
- lib/griffnode/api/account_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_account(opts = {}) ⇒ GetAccount200Response
Merchant plan, usage and limits.
-
#get_account_with_http_info(opts = {}) ⇒ Array<(GetAccount200Response, Integer, Hash)>
Merchant plan, usage and limits.
-
#get_stats(opts = {}) ⇒ GetStats200Response
Merchant transaction analytics.
-
#get_stats_with_http_info(opts = {}) ⇒ Array<(GetStats200Response, Integer, Hash)>
Merchant transaction analytics.
-
#initialize(api_client = ApiClient.default) ⇒ AccountApi
constructor
A new instance of AccountApi.
-
#list_balances(opts = {}) ⇒ ListBalances200Response
On-platform balances (for overage/top-up; NOT crypto settlement).
-
#list_balances_with_http_info(opts = {}) ⇒ Array<(ListBalances200Response, Integer, Hash)>
On-platform balances (for overage/top-up; NOT crypto settlement).
-
#list_invoices(opts = {}) ⇒ ListInvoices200Response
GriffNode billing invoices (platform ↔ merchant).
-
#list_invoices_with_http_info(opts = {}) ⇒ Array<(ListInvoices200Response, Integer, Hash)>
GriffNode billing invoices (platform ↔ merchant).
-
#list_plans(opts = {}) ⇒ ListPlans200Response
Plan catalogue and pricing.
-
#list_plans_with_http_info(opts = {}) ⇒ Array<(ListPlans200Response, Integer, Hash)>
Plan catalogue and pricing.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AccountApi
Returns a new instance of AccountApi.
19 20 21 |
# File 'lib/griffnode/api/account_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/griffnode/api/account_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_account(opts = {}) ⇒ GetAccount200Response
Merchant plan, usage and limits
25 26 27 28 |
# File 'lib/griffnode/api/account_api.rb', line 25 def get_account(opts = {}) data, _status_code, _headers = get_account_with_http_info(opts) data end |
#get_account_with_http_info(opts = {}) ⇒ Array<(GetAccount200Response, Integer, Hash)>
Merchant plan, usage and limits
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/griffnode/api/account_api.rb', line 33 def get_account_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.get_account ...' end # resource path local_var_path = '/account' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetAccount200Response' # auth_names auth_names = opts[:debug_auth_names] || ['SecretKey'] = opts.merge( :operation => :"AccountApi.get_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#get_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_stats(opts = {}) ⇒ GetStats200Response
Merchant transaction analytics
80 81 82 83 |
# File 'lib/griffnode/api/account_api.rb', line 80 def get_stats(opts = {}) data, _status_code, _headers = get_stats_with_http_info(opts) data end |
#get_stats_with_http_info(opts = {}) ⇒ Array<(GetStats200Response, Integer, Hash)>
Merchant transaction analytics
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/griffnode/api/account_api.rb', line 88 def get_stats_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.get_stats ...' end # resource path local_var_path = '/stats' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetStats200Response' # auth_names auth_names = opts[:debug_auth_names] || ['SecretKey'] = opts.merge( :operation => :"AccountApi.get_stats", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#get_stats\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_balances(opts = {}) ⇒ ListBalances200Response
On-platform balances (for overage/top-up; NOT crypto settlement)
135 136 137 138 |
# File 'lib/griffnode/api/account_api.rb', line 135 def list_balances(opts = {}) data, _status_code, _headers = list_balances_with_http_info(opts) data end |
#list_balances_with_http_info(opts = {}) ⇒ Array<(ListBalances200Response, Integer, Hash)>
On-platform balances (for overage/top-up; NOT crypto settlement)
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/griffnode/api/account_api.rb', line 143 def list_balances_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.list_balances ...' end # resource path local_var_path = '/balances' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListBalances200Response' # auth_names auth_names = opts[:debug_auth_names] || ['SecretKey'] = opts.merge( :operation => :"AccountApi.list_balances", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#list_balances\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_invoices(opts = {}) ⇒ ListInvoices200Response
GriffNode billing invoices (platform ↔ merchant)
192 193 194 195 |
# File 'lib/griffnode/api/account_api.rb', line 192 def list_invoices(opts = {}) data, _status_code, _headers = list_invoices_with_http_info(opts) data end |
#list_invoices_with_http_info(opts = {}) ⇒ Array<(ListInvoices200Response, Integer, Hash)>
GriffNode billing invoices (platform ↔ merchant)
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/griffnode/api/account_api.rb', line 202 def list_invoices_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.list_invoices ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AccountApi.list_invoices, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling AccountApi.list_invoices, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling AccountApi.list_invoices, must be greater than or equal to 0.' end # resource path local_var_path = '/invoices' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListInvoices200Response' # auth_names auth_names = opts[:debug_auth_names] || ['SecretKey'] = opts.merge( :operation => :"AccountApi.list_invoices", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#list_invoices\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_plans(opts = {}) ⇒ ListPlans200Response
Plan catalogue and pricing
263 264 265 266 |
# File 'lib/griffnode/api/account_api.rb', line 263 def list_plans(opts = {}) data, _status_code, _headers = list_plans_with_http_info(opts) data end |
#list_plans_with_http_info(opts = {}) ⇒ Array<(ListPlans200Response, Integer, Hash)>
Plan catalogue and pricing
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/griffnode/api/account_api.rb', line 271 def list_plans_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AccountApi.list_plans ...' end # resource path local_var_path = '/plans' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListPlans200Response' # auth_names auth_names = opts[:debug_auth_names] || ['SecretKey'] = opts.merge( :operation => :"AccountApi.list_plans", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountApi#list_plans\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |